@@ -27,11 +27,12 @@ class module_reference:
         str
     ] = None  # use as internal key to reference module (if None, use name)
     name: Optional[str] = None  # None if module exists only locally?
-    source: Optional[
-        str
-    ] = "registered"  # This config is deprecated. Please do not use.
+    source: Optional[str] = None  # This config is deprecated. Please do not use.
     yaml: Optional[str] = None
     version: Optional[str] = None
+    from_workspace: Optional[
+        bool
+    ] = False  # If set to True and it's a remote component, shrike will only attempt to load it from workspace (not from registry or feed)
 
 
 @dataclass
@@ -61,6 +62,7 @@ class module_loader_config:  # pylint: disable=invalid-name
         )
     )
     use_remote_when_component_not_in_manifest: Optional[bool] = False
+    loading_order: Optional[str] = "registry, feed, workspace"
 
 
 class AMLModuleLoader:
@@ -114,6 +116,12 @@ class AMLModuleLoader:
         self.feeds: List[str] = []
         self.registries: List[str] = []
 
+        self.loading_order = (
+            [x.strip().lower() for x in config.module_loader.loading_order.split(",")]
+            if "loading_order" in config.module_loader
+            else ["registry", "feed", "workspace"]
+        )
+
         # internal manifest built from yaml config
         self.modules_manifest = {}
         self.load_config_manifest(config)
@@ -126,6 +134,7 @@ class AMLModuleLoader:
             f", local_steps_folder={self.local_steps_folder}"
             f", use_remote_when_component_not_in_manifest={self.use_remote_when_component_not_in_manifest}"
             f", manifest={list(self.modules_manifest.keys())}"
+            f", loading_order={self.loading_order}"
             ")"
         )
         log.info(initialization_info_string)
@@ -232,12 +241,122 @@ class AMLModuleLoader:
 
         return loaded_module_class
 
-    def load_prod_module(self, module_name, module_version, module_namespace=None):
+    def solve_module_version_and_load(
+        self, module_name, module_version, module_cache_key, registry=None
+    ):
+        """Loads module class if exists
+
+        Args:
+            module_name (str): name of the module to load
+            module_version (str): version of the module to load
+            module_cache_key (str): cache key of the module after loading
+            registy (str): registry name if loading from a registry
+        """
+        module_version = solve_module_version(
+            module_name,
+            module_version,
+            workspace=current_workspace() if registry is None else None,
+            registry=registry,
+        )
+
+        loaded_module_class = Component.load(
+            current_workspace(),
+            name=module_name,
+            version=module_version,
+            registry=registry,
+        )
+
+        self.put_in_cache(module_cache_key, loaded_module_class)
+        return loaded_module_class
+
+    def load_prod_module_helper(
+        self,
+        module_name,
+        module_version,
+        module_cache_key,
+        module_namespace=None,
+        loading_order=None,
+    ):
+        """Loads module from available sources
+
+        Args:
+            module_name (str): name of the module to load
+            module_version (str): version of the module to load
+            module_cache_key (str): cache key of the module after loading
+            module_namespace (str): namespace of the module if applicable
+            loading_order (list[str]): custom loading order, if not specified loading order from config is used
+        """
+
+        if loading_order is None:
+            loading_order = self.loading_order
+
+        for source in loading_order:
+            if source == "registry":
+                log.info(f"Attempting to load {module_name} from registries...")
+                for registry in self.registries:
+                    try:
+                        log.info(
+                            f"Loading component {module_name} from registry {registry}"
+                        )
+
+                        loaded_module_class = self.solve_module_version_and_load(
+                            module_name, module_version, module_cache_key, registry
+                        )
+                        return loaded_module_class
+
+                    except BaseException as e:
+                        log.debug(f"Exception: {e}")
+
+            elif source == "feed":
+                log.info(f"Attempting to load {module_name} from feeds...")
+                for feed in self.feeds:
+                    try:
+                        log.info(f"Loading component {module_name} from feed {feed}")
+
+                        module_name = f"azureml.feed://{feed}/{module_name}"
+
+                        loaded_module_class = self.solve_module_version_and_load(
+                            module_name, module_version, module_cache_key
+                        )
+                        return loaded_module_class
+
+                    except BaseException as e:
+                        log.debug(f"Exception: {e}")
+
+            elif source == "workspace":
+                log.info(f"Attempting to load {module_name} from workspace...")
+                try:
+                    # try without namespace first
+                    return self.solve_module_version_and_load(
+                        module_name, module_version, module_cache_key
+                    )
+                except BaseException as e:
+                    # save the exception to raise it if namespace not provided
+                    if not module_namespace:
+                        raise e
+
+                log.info(
+                    f"    Trying to load module {module_name} with namespace {module_namespace}."
+                )
+                module_name = module_namespace + "://" + module_name
+                return self.solve_module_version_and_load(
+                    module_name, module_version, module_cache_key
+                )
+
+            else:
+                raise ValueError(
+                    f"Loading order contains incorrect key {i}. Please use a comma-separated str to order 'registry', 'feed', and 'workspace'."
+                )
+
+    def load_prod_module(
+        self, module_name, module_version, from_workspace=False, module_namespace=None
+    ):
         """Creates one module instance.
 
         Args:
             module_name (str) : module name
             module_version (str) : module version
+            from_workspace (bool) : attempt to load from workspace only
 
         Returns:
             object: module class loaded
@@ -254,83 +373,18 @@ class AMLModuleLoader:
         log.info(
             f"Loading remote module {module_cache_key} (name={module_name}, version={module_version}, namespace={module_namespace})"
         )
-        loading_raised_exception = None
 
-        for registry in self.registries:
-            try:
-                log.info(f"Loading component {module_name} from registry {registry}")
-
-                module_version = solve_module_version(
-                    module_name, module_version, registry=registry
-                )
-
-                loaded_module_class = Component.load(
-                    current_workspace(),
-                    name=module_name,
-                    version=module_version,
-                    registry=registry,
-                )
-                self.put_in_cache(module_cache_key, loaded_module_class)
-                return loaded_module_class
-
-            except BaseException as e:
-                log.debug(f"Exception: {e}")
-
-        for feed in self.feeds:
-            try:
-                log.info(f"Loading component {module_name} from feed {feed}")
-
-                module_name = f"azureml.feed://{feed}/{module_name}"
-
-                module_version = solve_module_version(
-                    module_name, module_version, workspace=current_workspace()
-                )
-
-                loaded_module_class = Component.load(
-                    current_workspace(),
-                    name=module_name,
-                    version=module_version,
-                )
-                self.put_in_cache(module_cache_key, loaded_module_class)
-                return loaded_module_class
-
-            except BaseException as e:
-                log.debug(f"Exception: {e}")
-
-        try:
-            # try without namespace first
-            module_version = solve_module_version(
-                module_name, module_version, workspace=current_workspace()
+        if from_workspace:
+            return self.load_prod_module_helper(
+                module_name,
+                module_version,
+                module_cache_key,
+                module_namespace,
+                loading_order=["workspace"],
             )
-
-            loaded_module_class = Component.load(
-                current_workspace(),
-                name=module_name,
-                version=module_version,
-            )
-        except BaseException as e:
-            # save the exception to raise it if namespace not provided
-            if not module_namespace:
-                raise e
-
-        if module_namespace:
-            log.info(
-                f"    Trying to load module {module_name} with namespace {module_namespace}."
-            )
-            module_name = module_namespace + "://" + module_name
-            module_version = solve_module_version(
-                module_name, module_version, workspace=current_workspace()
-            )
-
-            loaded_module_class = Component.load(
-                current_workspace(),
-                name=module_name,
-                version=module_version,
-            )
-
-        self.put_in_cache(module_cache_key, loaded_module_class)
-
-        return loaded_module_class
+        return self.load_prod_module_helper(
+            module_name, module_version, module_cache_key, module_namespace
+        )
 
     def get_module_manifest_entry(
         self, module_key, modules_manifest=None
@@ -392,11 +446,14 @@ class AMLModuleLoader:
                 loaded_module = self.load_prod_module(
                     module_entry["name"],
                     module_entry["version"],
+                    from_workspace=module_entry["from_workspace"]
+                    if "from_workspace" in module_entry
+                    else False,
                     module_namespace=module_namespace,
                 )
         else:
             log.warning(
-                f"The component '{module_key}' cannot be found in the manifest. Attempting to load it from the workspace."
+                f"The component '{module_key}' cannot be found in the manifest. Attempting to load the remote copy."
             )
             loaded_module = self.load_prod_module(module_entry["name"], None)
         return loaded_module
